# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = ['Schedule']


class Schedule(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_expression: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable: Optional[pulumi.Input[bool]] = None,
                 flow_name: Optional[pulumi.Input[str]] = None,
                 payload: Optional[pulumi.Input[str]] = None,
                 schedule_name: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Serverless Workflow Schedule resource.

        For information about Serverless Workflow Schedule and how to use it, see [What is Schedule](https://www.alibabacloud.com/help/en/doc-detail/168934.htm).

        > **NOTE:** Available in v1.105.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_flow = alicloud.fnf.Flow("exampleFlow",
            definition=\"\"\"  version: v1beta1
          type: flow
          steps:
            - type: pass
              name: helloworld
        \"\"\",
            description="tf-testaccFnFFlow983041",
            type="FDL")
        example_schedule = alicloud.fnf.Schedule("exampleSchedule",
            cron_expression="30 9 * * * *",
            description="tf-testaccFnFSchedule983041",
            enable=True,
            flow_name=example_flow.name,
            payload="{\"tf-test\": \"test success\"}",
            schedule_name="tf-testaccFnFSchedule983041")
        ```

        ## Import

        Serverless Workflow Schedule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:fnf/schedule:Schedule example <schedule_name>:<flow_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cron_expression: The CRON expression of the time-based schedule to be created.
        :param pulumi.Input[str] description: The description of the time-based schedule to be created.
        :param pulumi.Input[bool] enable: Specifies whether to enable the time-based schedule you want to create. Valid values: `false`, `true`.
        :param pulumi.Input[str] flow_name: The name of the flow bound to the time-based schedule you want to create.
        :param pulumi.Input[str] payload: The trigger message of the time-based schedule to be created. It must be in JSON object format.
        :param pulumi.Input[str] schedule_name: The name of the time-based schedule to be created.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if cron_expression is None:
                raise TypeError("Missing required property 'cron_expression'")
            __props__['cron_expression'] = cron_expression
            __props__['description'] = description
            __props__['enable'] = enable
            if flow_name is None:
                raise TypeError("Missing required property 'flow_name'")
            __props__['flow_name'] = flow_name
            __props__['payload'] = payload
            if schedule_name is None:
                raise TypeError("Missing required property 'schedule_name'")
            __props__['schedule_name'] = schedule_name
            __props__['last_modified_time'] = None
            __props__['schedule_id'] = None
        super(Schedule, __self__).__init__(
            'alicloud:fnf/schedule:Schedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cron_expression: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            enable: Optional[pulumi.Input[bool]] = None,
            flow_name: Optional[pulumi.Input[str]] = None,
            last_modified_time: Optional[pulumi.Input[str]] = None,
            payload: Optional[pulumi.Input[str]] = None,
            schedule_id: Optional[pulumi.Input[str]] = None,
            schedule_name: Optional[pulumi.Input[str]] = None) -> 'Schedule':
        """
        Get an existing Schedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cron_expression: The CRON expression of the time-based schedule to be created.
        :param pulumi.Input[str] description: The description of the time-based schedule to be created.
        :param pulumi.Input[bool] enable: Specifies whether to enable the time-based schedule you want to create. Valid values: `false`, `true`.
        :param pulumi.Input[str] flow_name: The name of the flow bound to the time-based schedule you want to create.
        :param pulumi.Input[str] last_modified_time: The time when the time-based schedule was last updated.
        :param pulumi.Input[str] payload: The trigger message of the time-based schedule to be created. It must be in JSON object format.
        :param pulumi.Input[str] schedule_id: The ID of the time-based schedule.
        :param pulumi.Input[str] schedule_name: The name of the time-based schedule to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["cron_expression"] = cron_expression
        __props__["description"] = description
        __props__["enable"] = enable
        __props__["flow_name"] = flow_name
        __props__["last_modified_time"] = last_modified_time
        __props__["payload"] = payload
        __props__["schedule_id"] = schedule_id
        __props__["schedule_name"] = schedule_name
        return Schedule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cronExpression")
    def cron_expression(self) -> pulumi.Output[str]:
        """
        The CRON expression of the time-based schedule to be created.
        """
        return pulumi.get(self, "cron_expression")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the time-based schedule to be created.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enable(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to enable the time-based schedule you want to create. Valid values: `false`, `true`.
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="flowName")
    def flow_name(self) -> pulumi.Output[str]:
        """
        The name of the flow bound to the time-based schedule you want to create.
        """
        return pulumi.get(self, "flow_name")

    @property
    @pulumi.getter(name="lastModifiedTime")
    def last_modified_time(self) -> pulumi.Output[str]:
        """
        The time when the time-based schedule was last updated.
        """
        return pulumi.get(self, "last_modified_time")

    @property
    @pulumi.getter
    def payload(self) -> pulumi.Output[Optional[str]]:
        """
        The trigger message of the time-based schedule to be created. It must be in JSON object format.
        """
        return pulumi.get(self, "payload")

    @property
    @pulumi.getter(name="scheduleId")
    def schedule_id(self) -> pulumi.Output[str]:
        """
        The ID of the time-based schedule.
        """
        return pulumi.get(self, "schedule_id")

    @property
    @pulumi.getter(name="scheduleName")
    def schedule_name(self) -> pulumi.Output[str]:
        """
        The name of the time-based schedule to be created.
        """
        return pulumi.get(self, "schedule_name")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

